//
//  MessageQueue.h
//  UniversalSMSUtilitites
//
//  Created by Andreas Fink on 27.02.09.
//  Copyright 2008-2014 Andreas Fink, Röschenzerstr. 27, 4058 Basel, Switzerland
//

#import <Foundation/Foundation.h>

#define		MAX_QUEUE_PRIORITIES	8

#define	PRIORITY_EMERGENCY	0
#define	PRIORITY_HIGH		1
#define	PRIORITY_MEDIUM		2
#define	PRIORITY_NORMAL		3
#define	PRIORITY_LOW		4
#define	PRIORITY_BULK		5
#define	PRIORITY_DLR		6
#define	PRIORITY_CLEANUP	7

@interface MessageQueue : NSObject
{
	int				fifoQueue;
	NSMutableArray	*messageQueue[MAX_QUEUE_PRIORITIES];
	NSMutableArray	*reportQueue[MAX_QUEUE_PRIORITIES];
	NSMutableArray	*ackNackQueue[MAX_QUEUE_PRIORITIES];
	NSLock			*queueLock[MAX_QUEUE_PRIORITIES];
	int				messageQueuePos;
	int				reportQueuePos;
	int				ackNackQueuePos;
}

- (MessageQueue *)initAsFifoQueue;
- (MessageQueue *)initAsPriorityQueue;
- (MessageQueue *)init;

- (void)	addMessageToQueue:(id) message priority:(int)p;
- (void)	addMessageToQueue:(id) message;
- (void)	addReportToQueue:(id) report priority:(int)p;
- (void)	addReportToQueue:(id) report;
- (void)	addAckNackToQueue:(id) message priority:(int)p;
- (void)	addAckNackToQueue:(id) message;
- (id)		getMessageFromQueue;
- (id)		getReportFromQueue;
- (id)		getAckNackFromQueue;
- (ssize_t)		messagesInQueue;
- (ssize_t)		reportsInQueue;
- (ssize_t)		ackNacksInQueue;

@end
